@@ -273,7 +273,7 @@ class Form:
 
         # Maybe wrap this in an Accordion widget
         wrapped_widget_list = widget_list
-        if not root:
+        if not root and len(schema["properties"]) > 1:
             wrapped_widget_list = self._wrap_accordion(widget_list, schema, label=label)
 
         def _getter():
@@ -434,7 +434,7 @@ class Form:
             getter=_getter,
             setter=_setter,
             resetter=_resetter,
-            widgets=[box_type(box)],
+            widgets=[box_type(box, layout=ipywidgets.Layout(width="100%"))],
             register_observer=_register_observer,
         )
 
@@ -712,10 +712,9 @@ class Form:
         )
 
     def _construct_anyof(self, schema, label=None, key="anyOf"):
-        # Maybe create an explanatory widget
-        title = []
-        if "title" in schema:
-            title = [ipywidgets.Label(schema["title"])]
+        # If this is a trivial anyOf rule, we omit it:
+        if len(schema[key]) == 1:
+            return self._construct(schema[key][0], label=label, root=False)
 
         # The list of subelements and their descriptive names
         names = []
@@ -764,7 +763,7 @@ class Form:
             getter=lambda: elements[names.index(selector.value)].getter(),
             setter=_setter,
             resetter=_resetter,
-            widgets=[ipywidgets.VBox(children=title + [widget])],
+            widgets=[ipywidgets.VBox(children=[widget])],
             subelements=elements,
             register_observer=_register_observer,
         )
